"""
Script to load data and generate figures 5 and 6.

Requires: python 2.7, numpy and matplotlib

T. Charrett
Cranfield University
2017
"""
import numpy as np
import matplotlib.pyplot as plt
plt.ion()

from mpl_toolkits.axes_grid1.inset_locator import inset_axes, zoomed_inset_axes
from mpl_toolkits.axes_grid1.inset_locator import mark_inset

#set math text style
import matplotlib as mpl
mpl.rcParams['mathtext.default'] = 'regular'

#%%-----------------------------------------------------------------------------
# load vx data
#-------------------------------------------------------------------------------
#data sets to load
vs = [-70,-60,-50,-40,-30,-20,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1, 0 ,1,2,3,4,5,6,7,8,9,10,20,30,40,50,60,70]

#indices in data sets to pull out (adjust indices to avoid acceleration/deceleration slopes)
i0 = 1400
i1 = 2400

vxx_means = []
vyx_means = []
vxx_errors = []
vyx_errors = []

for v in vs:
    data = np.load('Dx {0:+0.1f}mms-1.npz'.format(v))
    vx = data['vx'][i0:i1]
    vy = data['vy'][i0:i1]
    vxx_means.append(vx.mean())
    vyx_means.append(vy.mean())
    vxx_errors.append(vx.mean()-v)
    vyx_errors.append(vy.mean())

    print 'mean @{0:+0.1f}mm/s vx,vy : '.format(v), vx.mean(), vy.mean()
    print 'mean error vx,vy : ', vx.mean()-v, vy.mean()

del data

#%%-----------------------------------------------------------------------------
# load vy data
#-------------------------------------------------------------------------------
vs = [-70,-60,-50,-40,-30,-20,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1, 0 ,1,2,3,4,5,6,7,8,9,10,20,30,40,50,60,70]


#indices in data sets to pull out (adjust indices to avoid acceleration/deceleration slopes)
i0s = [1400]*len(vs)
i1s = [2400]*len(vs)

vxy_means = []
vyy_means = []
vxy_errors = []
vyy_errors = []

for v,i0,i1 in zip(vs,i0s,i1s):
    data = np.load('Dy {0:+0.1f}mms-1.npz'.format(v))
    vx = data['vx'][i0:i1]
    vy = data['vy'][i0:i1]
    vxy_means.append(vx.mean())
    vyy_means.append(vy.mean())
    vxy_errors.append(vx.mean())
    vyy_errors.append(vy.mean()-v)

    print 'mean @{0:+0.1f}mm/s vx,vy : '.format(v), vx.mean(), vy.mean()
    print 'mean error vx,vy : ', vx.mean(), vy.mean()-v

del data


#%%-----------------------------------------------------------------------------
# Figure vx linearity/error
#-------------------------------------------------------------------------------
f = plt.figure(figsize=(6,2.5))

ax1 = f.add_axes( (0.08,0.18,0.38,0.7))
ax2 = f.add_axes( (0.26,0.20,0.18,0.25)) #inset
ax3 = f.add_axes( (0.60,0.18,0.38,0.7))

ax1.set_title('(a) sensor linearity for $v_x$ motion')
ax1.set_xlabel('$v_x$ stage velocity [mm/s]')
ax1.set_ylabel('mean velocity\n[mm/s]')
ax1.plot(vs, vs, '--k')
ax1.hlines( 0, -90, 90, color='k', linestyles='--')
ax1.plot(vs, vxx_means, '-rx', ms=3)
ax1.plot(vs, vyx_means, '-b.', ms=4)
ax1.set_xlim( -70,70)
ax1.set_ylim(-70, +70)
ax1.set_xticks([-70,0,70])
ax1.set_yticks([-70,0,70])
ax1.yaxis.labelpad = -5
ax1.xaxis.labelpad = 0

mark_inset(ax1, ax2, loc1=1, loc2=3, fc="none", alpha=0.25)
ax2.spines['bottom'].set_alpha(0.25)
ax2.spines['top'].set_alpha(0.25)
ax2.spines['left'].set_alpha(0.25)
ax2.spines['right'].set_alpha(0.25)
ax2.plot(vs, vs, '--k')
ax2.hlines( 0, -90, 90, color='k', linestyles='--')
ax2.plot(vs, vxx_means, '-rx', ms=3)
ax2.plot(vs, vyx_means, '-b.', ms=4)
ax2.set_xlim( -10,10)
ax2.set_ylim(-10, +10)
ax2.set_xticks([])
ax2.set_yticks([])

ax3.set_title('(b) sensor accuracy/crosstalk for $v_x$ motion')
ax3.set_xlabel('$v_x$ stage velocity [mm/s]')
ax3.set_ylabel('velocity error\n[mm/s]')
ax3.hlines( 0, -80, 80, color='k', linestyles='--')
ax3.plot(vs, vxx_errors, '-rx', ms=3,lw=1.5)
ax3.plot(vs, vyx_errors, '-b.', ms=4,lw=1.5)
ax3.set_xlim( -70,70)
ax3.set_ylim(-0.012, +0.012)
ax3.set_xticks([-70,0,70])
ax3.set_yticks([-0.01,0,0.01])
ax3.yaxis.labelpad = 0
ax3.xaxis.labelpad = 0

#set font sizes
texts = f.findobj(plt.Text)
res = plt.setp(texts, fontsize=8)

f.savefig('fig5_vx.pdf', dpi=600, transparent=True)


#%%-----------------------------------------------------------------------------
# Figure acccuracy single col alternative
#-------------------------------------------------------------------------------
f = plt.figure(figsize=(6,2.5))

ax1 = f.add_axes( (0.08,0.18,0.38,0.7))
ax2 = f.add_axes( (0.26,0.20,0.18,0.25)) #inset
ax3 = f.add_axes( (0.60,0.18,0.38,0.7))

ax1.set_title('(a) sensor linearity for $v_y$ motion')
ax1.set_xlabel('$v_y$ stage velocity [mm/s]')
ax1.set_ylabel('mean velocity\n[mm/s]')
ax1.plot(vs, vs, '--k')
ax1.hlines( 0, -90, 90, color='k', linestyles='--')
ax1.plot(vs, vxy_means, '-rx', ms=3)
ax1.plot(vs, vyy_means, '-b.', ms=4)
ax1.set_xlim( -70,70)
ax1.set_ylim(-70, +70)
ax1.set_xticks([-70,0,70])
ax1.set_yticks([-70,0,70])
ax1.yaxis.labelpad = -5
ax1.xaxis.labelpad = 0

mark_inset(ax1, ax2, loc1=1, loc2=3, fc="none", alpha=0.25)
ax2.spines['bottom'].set_alpha(0.25)
ax2.spines['top'].set_alpha(0.25)
ax2.spines['left'].set_alpha(0.25)
ax2.spines['right'].set_alpha(0.25)
ax2.plot(vs, vs, '--k')
ax2.hlines( 0, -90, 90, color='k', linestyles='--')
ax2.plot(vs, vxy_means, '-rx', ms=3)
ax2.plot(vs, vyy_means, '-b.', ms=4)
ax2.set_xlim( -10,10)
ax2.set_ylim(-10, +10)
ax2.set_xticks([])
ax2.set_yticks([])

ax3.set_title('(b) sensor accuracy/crosstalk for $v_y$ motion')
ax3.set_xlabel('$v_y$ stage velocity [mm/s]')
ax3.set_ylabel('velocity error\n[mm/s]')
ax3.hlines( 0, -80, 80, color='k', linestyles='--')
ax3.plot(vs, vxy_errors, '-rx', ms=3,lw=1.5)
ax3.plot(vs, vyy_errors, '-b.', ms=4,lw=1.5)
ax3.set_xlim( -70,70)
ax3.set_ylim(-0.012, +0.012)
ax3.set_xticks([-70,0,70])
ax3.set_yticks([-0.01,0,0.01])
ax3.yaxis.labelpad = 0
ax3.xaxis.labelpad = 0

#set font sizes
texts = f.findobj(plt.Text)
res = plt.setp(texts, fontsize=8)

f.savefig('fig6_vy.pdf', dpi=600, transparent=True)