"""
Script to produce figure plots shown in figure 12b and figure 13

"""

import numpy as np

import matplotlib.pyplot as plt
plt.ion()

from mpl_toolkits.axes_grid1.inset_locator import inset_axes, zoomed_inset_axes
from mpl_toolkits.axes_grid1.inset_locator import mark_inset

#set math text style
import matplotlib as mpl
mpl.rcParams['mathtext.default'] = 'regular'

#%%-----------------------------------------------------------------------------
# load
#-------------------------------------------------------------------------------
data = np.loadtxt('exp_05_01_Str_A1_S7_W50.txt', delimiter=',')
    
t = data[:,0]
x = data[:,1]
y = data[:,2]
vx = data[:,3]
vy = data[:,4]
q = data[:,5]
k = np.ones(100)/100.0


#find final error
D = np.sqrt( x[-1]**2 + y[-1]**2)

#plt.figure('position')
#plt.plot(x,y, '-')

vx_ = np.convolve(vx,k, 'same')
#plt.figure('velocity vx')
#plt.plot(t,vx_, '-')

vy_ = np.convolve(vy,k, 'same')
#plt.figure('velocity vy')
#plt.plot(t,vy_, '-')

v = np.sqrt(vx**2 + vy**2)
v_ = np.convolve(v,k, 'same')

#%%-----------------------------------------------------------------------------
# fig 7 plot
#-------------------------------------------------------------------------------
f = plt.figure(figsize=(6,2.5))

ax1 = f.add_axes( (0.08,0.16,0.38,0.75))
ax2 = f.add_axes( (0.55,0.55,0.40,0.36))
ax3 = f.add_axes( (0.55,0.16,0.40,0.36))

#ax1.set_aspect('equal')
ax1.plot(x[:34300],y[:34300], '-')
ax1.set_xlabel('x position [$\mathsf{mm}$]')
ax1.set_ylabel('y position [$\mathsf{mm}$]')
ax1.set_xlim(-2, 27)
ax1.set_ylim(-52, 2)
plt.arrow( 0.5,-20, 0,-7,head_width=1, head_length=2, fc='k', ec='k')
plt.arrow( 3.5,-27, 0,+7,head_width=1, head_length=2, fc='k', ec='k')
patch = plt.Rectangle((-0.9, -51.0), 4.5, 4.0, facecolor="#BBBBBB", edgecolor='none')
ax1.add_patch(patch)
ax1.yaxis.labelpad = -5
ax1.xaxis.labelpad = 0

ax2.plot(t,vx, '-r', lw=1)
ax2.plot(t,vy, '-b', lw=1)
ax2.plot(t, vx_, '-k', lw=1.0)
ax2.plot(t, vy_, '-k', lw=1.0)
#ax2.set_xlabel(r'time [s]')
ax2.set_ylabel('velocity\n[mm/s]')
ax2.annotate('Vx', xy=(7.8, 1), xytext=(7.55, 10),
            arrowprops=dict(facecolor='black', shrink=0.01, width=0.25, headwidth=4.0))
ax2.annotate('Vy', xy=(8.4, -2.5), xytext=(8.5, -10),
            arrowprops=dict(facecolor='black', shrink=0.01, width=0.25, headwidth=4.0))
ax2.yaxis.labelpad = -5
ax2.xaxis.labelpad = 0     
ax2.set_xlim(7.5, 9.5)
ax2.set_yticks( [-10,0,10])
ax2.set_xticks( [])  
            
ax3.plot(t,v, '-r', lw=1)
ax3.plot(t, v_, '-k', lw=1.0)
ax3.set_xlabel('time [s]')
ax3.set_ylabel('toolspeed\n[mm/s]')
ax3.yaxis.labelpad = -1
ax3.xaxis.labelpad = 0   
ax3.set_xlim(7.5, 9.5)
ax3.set_ylim(2, 10)
ax3.set_ylim(0,12)
ax3.set_yticks( [0,5, 10])

#set font sizes
texts = f.findobj(plt.Text)
res = plt.setp(texts, fontsize=8)

#save file
f.savefig('fig7.pdf', dpi=600, transparent=True)



